Core JS
=======

> ## Warning:
>> This framework has not been thoroughly documented. A heavy re-architecture was implemented and configuration for documentation is outdated.

> CoreJS is a micro-framework for applying OOP principles in Javascript. It's main purpose is to not get in the way of traditional javascript development while supporting OOP methodologies. At its core is javascript prototypal inheritance with various utilities/helpers.

**Main features**

+ Core class
+ Event dispatching/Observer-broadcaster model (with memory management and scoping)
+ XHR implementation
+ Singleton patterns
+ Mixin implementation
+ Automated object instantiation from HTML DOM
+ Add-ons (work in progress)


Version
----
> 0.1.0

Bower Installation
--------------
    bower install core-js


Quickstart Guide
--------------


License
----

MIT
